

#include <Serial.h>



// pin definitions
const int redLED = 3;
const int greenLED = 5;
const int blueLED = 6;
const int inPin = 12;

//constants
const int DELAY_TIME = 10;
const int MAX_BRIGHT  = 255;

// The initial values of each color.
int red = 0;
int green = 170;
int blue = 170;
 
// Indicates whether a color is incrementing (1) or decrementing (0).
int incR = 1;
int incG = 1;
int incB = 0;


//target values for game
int targetRed;
int targetGreen;
int targetBlue;

//if the user has tried or not
boolean buttonPressed;

////////////////////////////////////////////////////////
////////////////////////////////////////////////////////
void setup() {
  Serial.begin(9600);
  
  //set the random seed
  randomSeed(analogRead(0));
  
  pinMode(redLED, OUTPUT);
  pinMode(greenLED, OUTPUT);
  pinMode(blueLED, OUTPUT);
  
  pinMode(inPin, INPUT);
  
  //to get the random color, we cycle through them using the transition method with a much chorter delay and stop at a random time to make sure that the target color is accomplishable.
  int cycles = random(100, 1000);
  for(int i = 0; i <= cycles; i++){
    setRandomColor();
  }
  targetRed = red;
  targetBlue = blue;
  targetGreen = green;
  
  //display the targets in serial for debugging purposes
  Sesrial.println(targetRed);
  Serial.println(targetGreen);
  Serial.println(targetBlue);
  
  //show the color on the LED. 
  analogWrite(redLED, targetRed);
  analogWrite(greenLED, targetGreen);
  analogWrite(blueLED, targetBlue);
  
  //reset the game, and the initial RGB values to default
  buttonPressed = false;
  red = 0;
  green = 170;
  blue = 170;
  //delay for a few seconds and then go to the loop
  delay(5000);
}

void setRandomColor()
{
  transition();
}

void transition()
{
  if (red >= MAX_BRIGHT)
    incR = 0;
  else if (red <= 0)
    incR = 1;
  if (green >= MAX_BRIGHT)
    incG = 0;
  else if (green <= 0)
    incG = 1;
  if (blue >= MAX_BRIGHT)
    incB = 0;
  else if (blue <= 0)
    incB = 1;
 
  if (incR)
    red++;
  else
    red--;
  if(incG)
    green++;
  else
    green--;
  if(incB)
    blue++;
  else
    blue--;
}

// Sets the output voltage on the LED pins.
void setColor()
{
  analogWrite(redLED, red);
  analogWrite(greenLED, green);
  analogWrite(blueLED, blue);

}

void loop() {
 
  if (digitalRead(inPin) == HIGH){
    buttonPressed = true;
    transition();
    setColor();
    delay(DELAY_TIME);
    

  }else{
    if(buttonPressed == false){ //if the user hasn't played the game yet, turn off the LED.
      analogWrite(redLED, 0);
      analogWrite(greenLED, 0);
      analogWrite(blueLED, 0);
    }
    else if(buttonPressed == true){
      Serial.println(red);
      Serial.println(green);
      Serial.println(blue);
      //check to see if user has landed near the target
      if(red >= (targetRed-30) && red <= (targetRed +30) &&
         green >= (targetGreen -20) && green <= (targetGreen +30) &&
         blue >= (targetBlue -30) && blue <= (targetBlue +30)){
           for(;;){ //flash green. Flashes forever; the reset button restarts the sketch. 
             analogWrite(redLED, 0);
             analogWrite(greenLED, MAX_BRIGHT);
             analogWrite(blueLED, 0);
             delay(100);
             analogWrite(greenLED, 0);
             delay(100);
         }    
    }else{ //flash red
      for(;;){ 
             analogWrite(redLED, MAX_BRIGHT);
             analogWrite(greenLED, 0);
             analogWrite(blueLED, 0);
             delay(100);
             analogWrite(redLED, 0);
             delay(100);
         }
    }
  }
 }
}
